@@ -14,24 +14,24 @@ def build_config() -> dict[str, str]:
     """
     return dict(
         # Python settings
-        python_version="3.11",
-        python_install_dir=r"/usr/local/lib/python3.11/site-packages/",
+        python_version="3.12",
+        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
         python_path=r"/usr/bin/python",
 
         # Package versions
         contourpy_version="1.2.1",
         meson_version="1.4.0",
-        mesonpy_version="0.15.0",
+        mesonpy_version="0.16.0",
         pybind11_version="2.12.0",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-ctjyr0ly/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-og6hp00g/lib/contourpy/util",
         source_dir=r"/build/python-contourpy/src/contourpy-1.2.1/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-ctjyr0ly/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-og6hp00g/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
